pub struct InitializationSpec {
pub constructor_name: String,
pub constructor_args: Vec<AbiValue>,
}Expand description
Specification for the initialization function of an account contract.
Fields
constructor_name: StringName of the initializer function in the contract artifact.
constructor_args: Vec<AbiValue>Arguments to pass to the initializer function.