Struct AuthWitValidity
pub struct AuthWitValidity {
pub is_valid_in_private: bool,
pub is_valid_in_public: bool,
}Expand description
Result of an authwit validity check.
Fields
is_valid_in_private: boolWhether the authwit is valid in private context (signature check).
is_valid_in_public: boolWhether the authwit is valid in public context (AuthRegistry check).