Struct SetPublicAuthWitInteraction
pub struct SetPublicAuthWitInteraction<'a, W> { /* private fields */ }Expand description
Convenience interaction for setting a public authwit in the AuthRegistry.
Wraps a call to AuthRegistry.set_authorized(message_hash, authorize).
Automatically enforces that only the authorizer (from) is the sender.
Mirrors TS SetPublicAuthwitContractInteraction.
Implementations
impl<'a, W> SetPublicAuthWitInteraction<'a, W>where
W: Wallet,
impl<'a, W> SetPublicAuthWitInteraction<'a, W>where
W: Wallet,
pub async fn create(
wallet: &'a W,
from: AztecAddress,
message_hash_or_intent: MessageHashOrIntent,
authorized: bool,
) -> Result<SetPublicAuthWitInteraction<'a, W>, Error>
pub async fn create( wallet: &'a W, from: AztecAddress, message_hash_or_intent: MessageHashOrIntent, authorized: bool, ) -> Result<SetPublicAuthWitInteraction<'a, W>, Error>
Create a new interaction for setting a public authwit.
Computes the message hash from the intent and chain info,
then constructs a call to AuthRegistry.set_authorized(hash, authorized).
pub fn request(&self) -> ExecutionPayload
pub fn request(&self) -> ExecutionPayload
Build the execution payload.
pub async fn simulate(
&self,
opts: SimulateOptions,
) -> Result<TxSimulationResult, Error>
pub async fn simulate( &self, opts: SimulateOptions, ) -> Result<TxSimulationResult, Error>
Simulate the interaction (sender is always from).
pub async fn send(&self, opts: SendOptions) -> Result<SendResult, Error>
pub async fn send(&self, opts: SendOptions) -> Result<SendResult, Error>
Send the interaction (sender is always from).
pub async fn profile(
&self,
opts: ProfileOptions,
) -> Result<TxProfileResult, Error>
pub async fn profile( &self, opts: ProfileOptions, ) -> Result<TxProfileResult, Error>
Profile the interaction (sender is always from).