Struct ContractDeployer
pub struct ContractDeployer<'a, W> { /* private fields */ }Expand description
Builder for deploying new contract instances.
Created with a contract artifact and wallet reference. Use
ContractDeployer::deploy to produce a DeployMethod for a
specific set of constructor arguments.
Implementations
impl<'a, W> ContractDeployer<'a, W>where
W: Wallet,
impl<'a, W> ContractDeployer<'a, W>where
W: Wallet,
pub fn new(artifact: ContractArtifact, wallet: &'a W) -> ContractDeployer<'a, W>
pub fn new(artifact: ContractArtifact, wallet: &'a W) -> ContractDeployer<'a, W>
Create a new deployer for the given artifact and wallet.
pub const fn with_public_keys(self, keys: PublicKeys) -> ContractDeployer<'a, W>
pub const fn with_public_keys(self, keys: PublicKeys) -> ContractDeployer<'a, W>
Set the public keys for the deployed instance.
pub fn with_constructor_name(
self,
name: impl Into<String>,
) -> ContractDeployer<'a, W>
pub fn with_constructor_name( self, name: impl Into<String>, ) -> ContractDeployer<'a, W>
Set the constructor function name (defaults to "constructor").
pub fn deploy(self, args: Vec<AbiValue>) -> Result<DeployMethod<'a, W>, Error>
pub fn deploy(self, args: Vec<AbiValue>) -> Result<DeployMethod<'a, W>, Error>
Create a DeployMethod for the given constructor arguments.
Validates the selected initializer, when present. Contracts with no initializer are allowed as long as no constructor arguments are passed.