pub struct PrivateKernelExecutionProver<'a, N>where
N: AztecNode,{ /* private fields */ }Expand description
Orchestrates private kernel proof generation.
Processes a private execution result through the full kernel circuit sequence:
- Init — first private call produces kernel public inputs
- Inner — each subsequent nested call chains with previous output
- Reset — between calls: squash transient side effects, verify reads
- Tail — finalize private kernel public inputs
- Hiding — wrap into privacy-preserving proof (to-rollup or to-public)
- ChonkProof — aggregate all execution steps into one proof
Implementations
Sourceimpl<'a, N> PrivateKernelExecutionProver<'a, N>where
N: AztecNode,
impl<'a, N> PrivateKernelExecutionProver<'a, N>where
N: AztecNode,
pub fn new( oracle: PrivateKernelOracle<'a, N>, prover: &'a dyn PrivateKernelProver, config: KernelExecutionConfig, ) -> PrivateKernelExecutionProver<'a, N>
Sourcepub fn from_stores(
node: &'a N,
contract_store: &'a ContractStore,
key_store: &'a KeyStore,
prover: &'a dyn PrivateKernelProver,
block_hash: Fr,
config: KernelExecutionConfig,
) -> PrivateKernelExecutionProver<'a, N>
pub fn from_stores( node: &'a N, contract_store: &'a ContractStore, key_store: &'a KeyStore, prover: &'a dyn PrivateKernelProver, block_hash: Fr, config: KernelExecutionConfig, ) -> PrivateKernelExecutionProver<'a, N>
Create from component stores and node.
Sourcepub async fn prove_with_kernels(
&self,
execution_results: &[PrivateCallExecution],
) -> Result<KernelProvingResult, Error>
pub async fn prove_with_kernels( &self, execution_results: &[PrivateCallExecution], ) -> Result<KernelProvingResult, Error>
Execute the full kernel proving sequence for a transaction.
Takes the private execution results (from ACVM execution) and processes them through the kernel circuit sequence.