SenderTaggingStore

Struct SenderTaggingStore 

pub struct SenderTaggingStore { /* private fields */ }
Stores sender tagging data for synchronizing sender tagging indexes.

Tracks pending indexes (used but not yet finalized) and finalized indexes (included in proven blocks) per directional app tagging secret.

Implementations

Source

impl SenderTaggingStore

pub fn new(kv: Arc<dyn KvStore>) -> SenderTaggingStore

pub async fn store_pending_indexes( &self, pre_tags: &[PreTag], ) -> Result<(), Error>

Store pending indexes from pre-tags.

Validates:

  • No duplicate secrets in pre-tags
  • Index is within WINDOW_LEN of finalized index
  • Index is greater than finalized index
  • No duplicate secret+txHash pairs with different indexes
pub async fn get_tx_hashes_of_pending_indexes( &self, secret: &Fr, from_index: u64, to_index: u64, ) -> Result<Vec<TxHash>, Error>

Get transaction hashes of pending indexes within a range.

pub async fn get_last_finalized_index(&self, secret: &Fr) -> Result<u64, Error>

Get the last finalized index for a secret.

pub async fn get_last_used_index(&self, secret: &Fr) -> Result<u64, Error>

Get the last used index (max of pending and finalized).

pub async fn get_next_index(&self, secret: &Fr) -> Result<u64, Error>

Get the next available tag index for a secret and increment.

pub async fn drop_pending_indexes( &self, tx_hashes: &[TxHash], ) -> Result<(), Error>

Drop pending indexes for dropped transactions.

pub async fn finalize_pending_indexes( &self, secret: &Fr, up_to_index: u64, ) -> Result<(), Error>

Finalize pending indexes: mark them as finalized and prune lower ones.

pub async fn get_all_pending( &self, ) -> Result<HashMap<Fr, Vec<PendingTagIndex>>, Error>

Get pending indexes as a map (secret → entries).