pub struct L2AmountClaim {
pub claim_amount: u128,
pub claim_secret: Fr,
pub message_leaf_index: u64,
}Expand description
Data required to claim bridged Fee Juice on L2.
This is produced by the L1 Fee Juice portal when a deposit is made,
and consumed by FeeJuicePaymentMethodWithClaim
to claim the deposit in the same transaction as fee payment.
Fields
claim_amount: u128Amount of Fee Juice being claimed (u128 in Noir).
claim_secret: FrSecret used to consume the L1-to-L2 message.
message_leaf_index: u64Index of the message leaf in the L1-to-L2 message tree.