pub struct NativeFeePaymentMethod { /* private fields */ }Expand description
Pays transaction fees using the sender’s existing Fee Juice balance.
This is the default fee payment strategy. It doesn’t add any extra function calls to the transaction — it simply declares who is paying. The sender must already have sufficient Fee Juice balance.
Implementations
Sourceimpl NativeFeePaymentMethod
impl NativeFeePaymentMethod
Sourcepub fn new(sender: AztecAddress) -> NativeFeePaymentMethod
pub fn new(sender: AztecAddress) -> NativeFeePaymentMethod
Create a new native fee payment method.
sender is the account that will pay fees from its existing Fee Juice balance.