pub struct SponsoredFeePaymentMethod { /* private fields */ }Expand description
A fee payment method where a sponsor contract pays the fee unconditionally.
This is the simplest strategy — useful for testing, development, and
gasless transaction experiences. The sponsor contract must be pre-funded
with Fee Juice and expose a sponsor_unconditionally() private function.
Implementations
Sourceimpl SponsoredFeePaymentMethod
impl SponsoredFeePaymentMethod
Sourcepub fn new(payment_contract: AztecAddress) -> SponsoredFeePaymentMethod
pub fn new(payment_contract: AztecAddress) -> SponsoredFeePaymentMethod
Create a new sponsored fee payment method.
payment_contract is the address of the sponsor contract that will pay fees.