pub struct WaitOpts {
pub timeout: Duration,
pub interval: Duration,
pub wait_for_status: TxStatus,
pub dont_throw_on_revert: bool,
pub ignore_dropped_receipts_for: Duration,
}Expand description
Options controlling wait_for_tx polling behavior.
Fields
timeout: DurationTotal timeout for the polling operation.
interval: DurationInterval between retries.
wait_for_status: TxStatusMinimum status to wait for.
dont_throw_on_revert: boolIf true, accept a reverted tx receipt without returning an error.
ignore_dropped_receipts_for: DurationDuration to ignore TxStatus::Dropped before treating it as failure.
Avoids race conditions where a tx briefly appears dropped before inclusion.