pub struct Fr(pub Fp<MontBackend<FrConfig, 4>, 4>);Expand description
A BN254 scalar field element.
This is the main field type used throughout the Aztec protocol for addresses, hashes, note values, and other scalar quantities.
Tuple Fields
0: Fp<MontBackend<FrConfig, 4>, 4>Implementations