Struct BatchCall
pub struct BatchCall<'a, W> { /* private fields */ }Expand description
A batch of interactions aggregated into a single transaction.
Merges multiple ExecutionPayloads into one, preserving all calls,
auth witnesses, capsules, and extra hashed args from each payload.
The fee payer is taken from the last payload that specifies one.
Implementations
impl<'a, W> BatchCall<'a, W>where
W: Wallet,
impl<'a, W> BatchCall<'a, W>where
W: Wallet,
pub const fn new(
wallet: &'a W,
payloads: Vec<ExecutionPayload>,
) -> BatchCall<'a, W>
pub const fn new( wallet: &'a W, payloads: Vec<ExecutionPayload>, ) -> BatchCall<'a, W>
Create a new batch from a list of execution payloads.
pub fn request(&self) -> Result<ExecutionPayload, Error>
pub fn request(&self) -> Result<ExecutionPayload, Error>
Merge all payloads into a single ExecutionPayload.
pub async fn simulate(
&self,
opts: SimulateOptions,
) -> Result<TxSimulationResult, Error>
pub async fn simulate( &self, opts: SimulateOptions, ) -> Result<TxSimulationResult, Error>
Simulate the batch without sending.
pub async fn profile(
&self,
opts: ProfileOptions,
) -> Result<TxProfileResult, Error>
pub async fn profile( &self, opts: ProfileOptions, ) -> Result<TxProfileResult, Error>
Profile the batch as a single transaction.
pub async fn send(&self, opts: SendOptions) -> Result<SendResult, Error>
pub async fn send(&self, opts: SendOptions) -> Result<SendResult, Error>
Send the batch as a single transaction.