pub struct EmbeddedPxe<N>where
N: AztecNode,{ /* private fields */ }Expand description
Embedded PXE that runs private execution logic in-process.
In-process PXE for Aztec v4.x where PXE runs client-side.
Talks to the Aztec node via node_* RPC methods and maintains local
stores for contracts, keys, addresses, notes, capsules, and events.
Phase 3 additions: anchor block tracking, block reorg handling, private event retrieval, transaction profiling, and persistent storage.
Implementations
Sourceimpl<N> EmbeddedPxe<N>
impl<N> EmbeddedPxe<N>
Sourcepub async fn create(
node: N,
kv: Arc<dyn KvStore>,
) -> Result<EmbeddedPxe<N>, Error>
pub async fn create( node: N, kv: Arc<dyn KvStore>, ) -> Result<EmbeddedPxe<N>, Error>
Create a new EmbeddedPxe backed by the given node client and KV store.
Sourcepub async fn create_with_prover_config(
node: N,
kv: Arc<dyn KvStore>,
prover_config: BbProverConfig,
) -> Result<EmbeddedPxe<N>, Error>
pub async fn create_with_prover_config( node: N, kv: Arc<dyn KvStore>, prover_config: BbProverConfig, ) -> Result<EmbeddedPxe<N>, Error>
Create a new EmbeddedPxe with custom BB prover configuration.
Sourcepub async fn create_with_config(
node: N,
kv: Arc<dyn KvStore>,
config: EmbeddedPxeConfig,
) -> Result<EmbeddedPxe<N>, Error>
pub async fn create_with_config( node: N, kv: Arc<dyn KvStore>, config: EmbeddedPxeConfig, ) -> Result<EmbeddedPxe<N>, Error>
Create a new EmbeddedPxe with full configuration.
Sourcepub async fn create_ephemeral(node: N) -> Result<EmbeddedPxe<N>, Error>
pub async fn create_ephemeral(node: N) -> Result<EmbeddedPxe<N>, Error>
Create a new EmbeddedPxe with an in-memory KV store.
Sourcepub fn contract_store(&self) -> &ContractStore
pub fn contract_store(&self) -> &ContractStore
Get a reference to the contract store.
Sourcepub fn address_store(&self) -> &AddressStore
pub fn address_store(&self) -> &AddressStore
Get a reference to the address store.
Sourcepub fn note_store(&self) -> &NoteStore
pub fn note_store(&self) -> &NoteStore
Get a reference to the note store.
Sourcepub fn anchor_block_store(&self) -> &AnchorBlockStore
pub fn anchor_block_store(&self) -> &AnchorBlockStore
Get a reference to the anchor block store.
Sourcepub fn private_event_store(&self) -> &PrivateEventStore
pub fn private_event_store(&self) -> &PrivateEventStore
Get a reference to the private event store.