pub struct NoteService<'a, N>where
N: AztecNode,{ /* private fields */ }Expand description
Service for note-related operations.
Implementations
Sourceimpl<'a, N> NoteService<'a, N>where
N: AztecNode,
impl<'a, N> NoteService<'a, N>where
N: AztecNode,
pub fn new(node: &'a N, note_store: &'a NoteStore) -> NoteService<'a, N>
Sourcepub async fn get_notes(
&self,
filter: &NoteFilter,
) -> Result<Vec<StoredNote>, Error>
pub async fn get_notes( &self, filter: &NoteFilter, ) -> Result<Vec<StoredNote>, Error>
Get notes from the store matching a filter.
Sourcepub async fn sync_note_nullifiers(
&self,
contract_address: &AztecAddress,
scopes: &[AztecAddress],
anchor_block_number: u64,
) -> Result<u64, Error>
pub async fn sync_note_nullifiers( &self, contract_address: &AztecAddress, scopes: &[AztecAddress], anchor_block_number: u64, ) -> Result<u64, Error>
Sync note nullifiers for a contract.
Fetches all active notes for a contract and checks if their nullifiers have been included in the nullifier tree (i.e., the note was spent). If so, marks the note as nullified.
Batches queries for efficiency using MAX_RPC_LEN.
Sourcepub async fn validate_and_store_note(
&self,
note: &StoredNote,
scope: &AztecAddress,
) -> Result<(), Error>
pub async fn validate_and_store_note( &self, note: &StoredNote, scope: &AztecAddress, ) -> Result<(), Error>
Validate and store a note.
Validates:
- Note hash exists in the note hash tree
- Note is not already nullified
- Computes siloed hash and nullifier
Then stores the note in the NoteStore.